@@ -12,9 +12,12 @@ use Hash::Util qw(lock_hashref);
 use Module::Load;
 use Types::Standard qw(InstanceOf HashRef);
 
-our $VERSION = '0.61';
+our $VERSION = '0.70';
 
-plugin_keywords qw(validate errors validator_language);
+# Global var for saving last success validation valid input.
+my $valid_input;
+
+plugin_keywords qw(validate validated errors);
 
 has config_obj => (
     is       => 'ro',
@@ -69,21 +72,42 @@ sub BUILD {
     );
 }
 
-sub validator_language {
-    shift->config_obj->language(shift);
-    return;
+sub validate {
+    my ($self, %params) = @_;
+
+    my $profile = %params{profile};
+    my $input   = %params{input} // $self->dsl->body_parameters->as_hashref_mixed;
+    my $lang    = %params{lang};
+
+    if (defined $lang) {
+        $self->_validator_language($lang);
+    }
+
+    # We need to unset value of this global var.
+    $valid_input = undef;
+
+    my $result = $self->_validate($input, $profile);
+
+    if ($result->success) {
+        $valid_input = $result->valid;
+        return $valid_input;
+    }
+
+    return undef;
 }
 
-sub validate {
-    my ($self, $profile) = @_;
+sub validated {
+    return $valid_input;
+}
 
-    autoload $profile;
+sub errors {
+    return shift->_get_deferred->{messages};
+}
 
-    my $input  = $self->dsl->body_parameters->as_hashref_mixed;
-    my $result = $self->_validate($input, $profile->new);
-
-    return $result->success ? $result->valid : undef;
 
+sub _validator_language {
+    shift->config_obj->language(shift);
+    return;
 }
 
 sub _validate {
@@ -150,10 +174,6 @@ sub _registry {
     );
 }
 
-sub errors {
-    return shift->_get_deferred->{messages};
-}
-
 sub _get_deferred {
     my $self = shift;
 
@@ -175,14 +195,31 @@ Dancer2::Plugin::FormValidator - neat and easy to start form validation plugin f
 
 =head1 VERSION
 
-version 0.61
+version 0.70
 
 =head1 SYNOPSIS
 
     use Dancer2::Plugin::FormValidator;
 
+    package RegisterForm {
+         use Moo;
+         with 'Dancer2::Plugin::FormValidator::Role::Profile';
+
+         sub profile {
+            return {
+                username     => [ qw(required alpha_num_ascii length_min:4 length_max:32) ],
+                email        => [ qw(required email length_max:127) ],
+                password     => [ qw(required length_max:40) ],
+                password_cnf => [ qw(required same:password) ],
+                confirm      => [ qw(required accepted) ],
+            };
+        };
+    }
+
     post '/form' => sub {
-        if (my $valid_hash_ref = validate 'App::Http::Forms::RegisterForm') {
+        if (validate profile => RegisterForm->new) {
+            my $valid_hash_ref = validated;
+
             save_user_input($valid_hash_ref);
             redirect '/success_page';
         }
@@ -198,9 +235,6 @@ Interfaces may change in future:
 
 =over 4
 
-=item *
-Template tokens: errors.
-
 =item *
 Roles: Dancer2::Plugin::FormValidator::Role::Extension, Dancer2::Plugin::FormValidator::Role::Validator.
 
@@ -214,10 +248,10 @@ Won't change:
 =over 4
 
 =item *
-Dsl keywords: validator_language, errors.
+Dsl keywords.
 
 =item *
-Template tokens: old.
+Template tokens.
 
 =item *
 Roles: Dancer2::Plugin::FormValidator::Role::Profile, Dancer2::Plugin::FormValidator::Role::HasMessages, Dancer2::Plugin::FormValidator::Role::ProfileHasMessages.
@@ -232,7 +266,7 @@ Help is always welcome!
 =head1 DESCRIPTION
 
 This is micro-framework that provides validation in your Dancer2 application.
-It consists of dsl's keywords and a set of agreements.
+It consists of dsl's keywords: validate, validator_language, errors.
 It has a set of built-in validators that can be extended by compatible modules (extensions).
 Also proved runtime switching between languages, so you can show proper error messages to users.
 
@@ -245,20 +279,20 @@ at least one main role: Dancer2::Plugin::FormValidator::Role::Profile.
 
 This role requires profile method which should return a HashRef Data::FormValidator accepts:
 
-    package App::Http::Forms::RegisterForm {
-        use Moo;
-        with 'Dancer2::Plugin::FormValidator::Role::Profile';
+    package RegisterForm
 
-        sub profile {
-            return {
-                username     => [ qw(required alpha_num_ascii length_min:4 length_max:32) ],
-                email        => [ qw(required email length_max:127) ],
-                password     => [ qw(required length_max:40) ],
-                password_cnf => [ qw(required same:password) ],
-                confirm      => [ qw(required accepted) ],
-            };
+    use Moo;
+    with 'Dancer2::Plugin::FormValidator::Role::Profile';
+
+    sub profile {
+        return {
+            username     => [ qw(required alpha_num_ascii length_min:4 length_max:32) ],
+            email        => [ qw(required email length_max:127) ],
+            password     => [ qw(required length_max:40) ],
+            password_cnf => [ qw(required same:password) ],
+            confirm      => [ qw(required accepted) ],
         };
-    }
+    };
 
 =head2 Application
 
@@ -275,9 +309,10 @@ Then you need to set basic configuration:
 Now you can validate POST parameters in your controller:
 
     use Dancer2::Plugin::FormValidator;
+    use RegisterForm;
 
     post '/register' => sub {
-        if (my $valid_hash_ref = validate 'App::Http::Forms::RegisterForm') {
+        if (my $valid_hash_ref = validate profile => RegisterForm->new) {
             if (login($valid_hash_ref)) {
                 redirect '/success_page';
             }
@@ -332,6 +367,13 @@ Template app/register:
                 <: for $errors[email] -> $error { :>
                     <small class="pl-1 text-red-400"><: $error :></small>
                 <: } :>
+
+            <!-- Other fields -->
+            ...
+            ...
+            ...
+            <!-- Other fields end -->
+
             </div>
             <button
                     type="submit"
@@ -348,14 +390,14 @@ Template app/register:
     plugins:
         FormValidator:
             session:
-                namespace: '_form_validator' # this is required
+                namespace: '_form_validator'         # this is required
             messages:
-                language: en                 # this is default
-                ucfirst: 1                   # this is default
+                language: en                         # this is default
+                ucfirst: 1                           # this is default
                 validators:
                     required:
-                        en: %s is needed from config
-                        de: %s ist erforderlich
+                        en: %s is needed from config # custom en message
+                        de: %s ist erforderlich      # custom de message
                     ...
             extensions:
                 dbic:
@@ -367,20 +409,47 @@ Template app/register:
 
 =head3 validate
 
-    my $valid_hash_ref = validate $profile_class
+    my $valid_hash_ref = validate(Hash $params): HashRef|undef
 
-Returns $valid_hash_ref if validation succeed, otherwise returns undef.
+Accept params as hash:
 
-=head3 validator_language
+    (
+        profile => Object implementing Dancer2::Plugin::FormValidator::Role::Profile # required
+        input   => HashRef of values to validate, default is body_parameters->as_hashref_mixed
+        lang    => Accepts two-lettered language id, default is 'en'
+    )
 
-    validator_language $lang
+Profile is required, input and lang is optional.
+
+Returns valid input HashRef if validation succeed, otherwise returns undef.
+
+    if (my $valid_hash_ref = validate 'RegisterForm') {
+        # Success, data is valid.
+        # Do some operations...
+    }
+    else {
+        # Error, data is invalid.
+        # Redirect or show errors...
+    }
+
+=head3 validated
+
+    validated(): HashRef|undef
+
+No arguments.
+Returns valid input HashRef if validate succeed.
+
+    my $valid_hash_ref = validated;
 
 =head3 errors
 
-    my $errors_hash_multi = errors
+    errors(): HashRef
 
+No arguments.
 Returns HashRef[ArrayRef] if validation failed.
 
+    my $errors_hash_multi = errors;
+
 =head1 Validators
 
 =head3 accepted
